@@ -1,8 +1,8 @@
 # frozen_string_literal: true
 
-require 'test_helper'
+require_relative 'test_helper'
 
-class Bzip2SupportTest < MiniTest::Test
+class Bzip2SupportTest < Minitest::Test
   BZIP2_ZIP_TEST_FILE = 'test/data/zipWithBzip2Compression.zip'
 
   def test_read
